asciiframe 1.2.0

Watch any video in the terminal with ASCII
docs.rs failed to build asciiframe-1.2.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: asciiframe-2.0.0

Note: I am relatively new to rust so any sort of suggestions, questions, and contributions are completely welcome!

How To Use

Usage

$ asc [OPTIONS] --file <FILE>

Options

File

-f, --file <FILE

Specify the input video file to be convertered

Output

-o, --output <OUTPUT>

Optional filename for asciiframe to write rendered output to, which can be run later to display the video

Installation

Crates.io

cargo install asciiframe

Make sure ~/.cargo/bin is in your path

Git

Clone the repository then install it with

cargo install --path .

Make sure ~/.cargo/bin is in your path

Contributing

Building from source

To build from source, you'll need opencv and clang

About

Authors and Contributors

License

MIT License